@@ -19,12 +19,7 @@ class RegionUri:
 
 
 def region_resolve(region: Region, uris: List[RegionUri]) -> RegionUri:
-    if region == Region.Europe:
-        return uris[0]
-    elif region == Region.America:
-        return uris[1]
-    elif region == Region.Switzerland:
-        return uris[2]
-    elif region == Region.Singapore:
-        return uris[3]
+    for x in uris:
+        if x.region == region:
+            return x
     return None
